import { Controller, Get, Query, Param } from '@nestjs/common';

// 定义商品相关的控制器，路由前缀为 /goods
@Controller('goods')
export class GoodsController {
    // 构造函数，在控制器实例化时执行
    constructor() {
        console.log('goods controller') // 打印日志，用于调试
    }
    // 示例1：基本查询参数
    // GET /goods/hello?name=xxx
    @Get('hello')
    getHello(@Query('name') name?: string) {
        return { 
            message: 'Hello World!', // 固定返回消息
            name: name || 'Guest' // 返回传入的name参数，如果未传入则返回'Guest'
        };
    }

    // 示例2：路径参数
    // GET /goods/detail/123
    @Get('detail/:id')
    getDetail(@Param('id') id: string) {
        return {
            id: id, // 返回路径参数中的id
            detail: `Detail for product ${id}` // 返回包含id的详细信息
        };
    }

    // 示例3：多个查询参数
    // GET /goods/search?keyword=xxx&page=2&limit=20
    @Get('search')
    searchProducts(
        @Query('keyword') keyword: string, // 搜索关键词
        @Query('page') page: number = 1, // 页码，默认值为1
        @Query('limit') limit: number = 10 // 每页数量，默认值为10
    ) {
        return {
            keyword, // 返回搜索关键词
            page, // 返回当前页码
            limit, // 返回每页数量
            results: [] // 返回搜索结果（示例中为空数组）
        };
    }
}